using System;
using System.Collections.Generic;
using Jypeli;
using Jypeli.Assets;
using Jypeli.Controls;
using Jypeli.Widgets;

namespace pomppu_possu;

/// @author suvitoivanen
/// @version 14.02.2025
/// <summary>
/// Eeppinen tasohyppely peli
/// </summary>
/// Kenttä pitää vielä luoda tekstitiedostoa käyttäen
/// Täytyy lisätä hyppy käskyihin
/// Lisäsin kuvat Content kansioon mutta ohjelma ei käänny nyt
/// Vaihtelin muutamia nimiä, kun herjasi niitä keltasena
public class PomppuPossu : PhysicsGame
{
    private Image _pomppuPossunKuva = LoadImage("pomppupossu.png");
    private Image _porkkanaKuva = LoadImage("porkkananKuva.png");

    private SoundEffect _pisteAani = LoadSoundEffect("maali.wav");

    public override void Begin()
    {
        // Lisäsin painovoiman
        Gravity = new Vector(0, -1000);
        
        Level.Size = new Vector(1920, 1080);
        SetWindowSize(1920, 1080);
        CenterWindow();
        Camera.ZoomToAllObjects(100);
        Level.CreateBorders();
        Level.Background.Color = Color.SpringGreen;

        PhysicsObject pomppuPossu = new PhysicsObject(30, 80, Shape.Rectangle);
        pomppuPossu.Image = _pomppuPossunKuva;
        Add(pomppuPossu);

        Keyboard.Listen(Key.Up, ButtonState.Down, Liikuta, "Liikuttaa pelaajaa ylös", pomppuPossu, new Vector(0,1000));
        Keyboard.Listen(Key.Down, ButtonState.Down, Liikuta, "Liikuttaa pelaajaa alas", pomppuPossu, new Vector(0,-1000));
        Keyboard.Listen(Key.Left, ButtonState.Down, Liikuta, "Liikuttaa pelaajaa vasemmalle", pomppuPossu, new Vector(-1000,0));
        Keyboard.Listen(Key.Right, ButtonState.Down, Liikuta, "Liikuttaa pelaajaa oikealle", pomppuPossu, new Vector(1000,0));

        for (int i = 0; i < 10; i++)
        {
            Color[] varit = { Color.Black, Color.White };
            Megaporkkanat megaporkkana = new Megaporkkanat(60, 60, varit);
            megaporkkana.Shape = Shape.Circle;
            megaporkkana.Position = RandomGen.NextVector(Level.BoundingRect);
            megaporkkana.Image = _porkkanaKuva;
            AddCollisionHandler<PhysicsObject, Megaporkkanat>(pomppuPossu, megaporkkana, TormattiinEsineeseen);
            Add(megaporkkana);
        }
        
        for (int i = 0; i < 5; i++)
        {
            Tasot paikallaan = new Tasot(150, 20);
            paikallaan.MakeStatic();
            paikallaan.Position = RandomGen.NextVector(Level.BoundingRect);
            Add(paikallaan);
        }
        
        
        Keyboard.Listen(Key.Escape, ButtonState.Pressed, ConfirmExit, "Lopeta peli");
    }

    public void TormattiinEsineeseen(PhysicsObject tormaaja, Megaporkkanat kohde)
    {
        kohde.OtaVastaanOsuma();
        _pisteAani.Play(); // Yritin lisätä megaporkkanoihin, en osannu xD
        MessageDisplay.Add("Megaporkkana kerätty!"); //Lisäsin viestin
    }

    /// <summary>
    /// Liikuttaa fysiikkaoliota.
    /// </summary>
    /// <param name="liikuteltava">Liikutettava</param>
    /// <param name="suunta">Suunta</param>
    public void Liikuta(PhysicsObject liikuteltava, Vector suunta)
    {
        liikuteltava.Push(suunta);
    }
        // Pomppu possun megamaailma

        
}


